@@ -26,7 +26,7 @@
 #endif
 
 #include <libringtoned/debug.h>
-#include <libringtoned/player.h>
+#include <libringtoned/decoder.h>
 #include <libringtoned/profile.h>
 
 #ifdef MUST_UNDEF_RINGTONED_IS_COMPILING_LIB
