@@ -117,7 +117,7 @@ bus_watch_cb (GstBus     *bus,
     switch (GST_MESSAGE_TYPE (msg))
     {
         case GST_MESSAGE_EOS:
-            DEBUG ("Finished playing %s");
+            DEBUG ("Finished playing");
             self->priv->playing = FALSE;
             break;
 
