@@ -21,7 +21,6 @@
 #define __RINGTONED_CALL_PRIVATE_H__
 
 #include "call.h"
-#include "canberra/canberra.h"
 
 
 G_BEGIN_DECLS
@@ -29,8 +28,7 @@ G_BEGIN_DECLS
 RingtonedCall *     ringtoned_call_new                  (TpChannel      *channel,
                                                          const gchar    *vcard_field,
                                                          const gchar    *identifier,
-                                                         McAccount      *account,
-                                                         ca_context     *ca_ctx);
+                                                         McAccount      *account);
 
 G_END_DECLS
 
