@@ -61,6 +61,7 @@ struct _RingtonedCallPrivate
 
     gchar *ringtone_path;
     GstElement *pipeline;
+    guint playing_timeout_id;
 };
 
 G_DEFINE_TYPE (RingtonedCall, ringtoned_call, G_TYPE_OBJECT)
@@ -122,6 +123,19 @@ bus_watch_cb (GstBus     *bus,
     return TRUE;
 }
 
+static gboolean
+play_real (gpointer user_data)
+{
+    RingtonedCall *self = user_data;
+
+    g_assert (self->priv->pipeline);
+    gst_element_set_state (self->priv->pipeline, GST_STATE_PLAYING);
+
+    self->priv->playing_timeout_id = 0;
+
+    return FALSE;
+}
+
 void
 ringtoned_call_play_ringtone (RingtonedCall *self)
 {
@@ -188,7 +202,10 @@ ringtoned_call_play_ringtone (RingtonedCall *self)
     gst_bus_add_watch (bus, bus_watch_cb, self);
 
     DEBUG ("Actually playing %s", playable);
-    gst_element_set_state (self->priv->pipeline, GST_STATE_PLAYING);
+
+    /* Ringtoned is faster than the call-ui and we want to avoid playing the
+     * ringtone too long before the UI is displayed */
+    self->priv->playing_timeout_id = g_timeout_add (500, play_real, self);
 
     gst_object_unref (bus);
     g_free (playable);
@@ -202,6 +219,13 @@ stop_ringtone (RingtonedCall *self)
     if (self->priv->pipeline)
     {
         DEBUG ("Stop playing %s", self->priv->ringtone_path);
+
+        if (self->priv->playing_timeout_id)
+        {
+            g_source_remove (self->priv->playing_timeout_id);
+            self->priv->playing_timeout_id = 0;
+        }
+
         gst_element_set_state (self->priv->pipeline, GST_STATE_NULL);
         gst_object_unref (self->priv->pipeline);
         self->priv->pipeline = NULL;
