@@ -85,8 +85,6 @@ struct _RingtonedDispatcherPrivate
 
     /* Pulse context for setting the volume */
     pa_context *pa_ctx;
-    /* Canberra context for setting the volume */
-    ca_context *ca_ctx;
 };
 
 G_DEFINE_TYPE (RingtonedDispatcher, ringtoned_dispatcher, G_TYPE_OBJECT)
@@ -274,8 +272,7 @@ observer_new_channel_cb (RingtonedFakeTpObserver *observer,
     profile = mc_profile_lookup (profile_name);
     vcard_field =  mc_profile_get_vcard_field (profile);
 
-    call = ringtoned_call_new (channel, vcard_field, identifier, account,
-            self->priv->ca_ctx);
+    call = ringtoned_call_new (channel, vcard_field, identifier, account);
 
     self->priv->calls = g_list_prepend (self->priv->calls, call);
     g_object_weak_ref (G_OBJECT (call), call_destroyed_cb, self);
@@ -523,12 +520,6 @@ ringtoned_dispatcher_constructed (GObject *object)
      * happen */
     setup_pulseaudio_context (self);
 
-    /* Canberra context used to play the ringtones. Opening it can take a
-     * tiny bit of time, so we just keep one around */
-    ca_context_create (&self->priv->ca_ctx);
-    ca_context_set_driver (self->priv->ca_ctx, "pulse");
-    ca_context_open (self->priv->ca_ctx);
-
     if (G_OBJECT_CLASS (ringtoned_dispatcher_parent_class)->constructed)
         G_OBJECT_CLASS (ringtoned_dispatcher_parent_class)->constructed (object);
 }
@@ -569,8 +560,6 @@ ringtoned_dispatcher_finalize (GObject *object)
     if (self->priv->pa_ctx)
         pa_context_unref (self->priv->pa_ctx);
 
-    ca_context_destroy (self->priv->ca_ctx);
-
     G_OBJECT_CLASS (ringtoned_dispatcher_parent_class)->finalize (object);
 }
 
